@@ -395,96 +395,6 @@ gdm_display_add_user_authorization (GdmDisplay *self,
         return TRUE;
 }
 
-void
-gdm_display_get_timed_login_details (GdmDisplay *self,
-                                     gboolean   *enabledp,
-                                     char      **usernamep,
-                                     int        *delayp)
-{
-        gboolean res;
-        gboolean enabled;
-        int      delay;
-        char    *username = NULL;
-
-        enabled = FALSE;
-        username = NULL;
-        delay = 0;
-
-        if (!self->priv->allow_timed_login) {
-                goto out;
-        }
-
-#ifdef WITH_SYSTEMD
-        /* FIXME: More careful thought needs to happen before we
-         * can support auto/timed login on auxilliary seats in the
-         * systemd path.
-         */
-        if (LOGIND_RUNNING()) {
-                if (g_strcmp0 (self->priv->seat_id, "seat0") != 0) {
-                        goto out;
-                }
-        }
-#endif
-
-        res = gdm_settings_direct_get_boolean (GDM_KEY_AUTO_LOGIN_ENABLE, &enabled);
-        if (res && enabled) {
-            res = gdm_settings_direct_get_string (GDM_KEY_AUTO_LOGIN_USER, &username);
-        }
-
-        if (enabled && res && username != NULL && username[0] != '\0') {
-                goto out;
-        }
-
-        g_free (username);
-        username = NULL;
-        enabled = FALSE;
-
-        res = gdm_settings_direct_get_boolean (GDM_KEY_TIMED_LOGIN_ENABLE, &enabled);
-        if (res && ! enabled) {
-                goto out;
-        }
-
-        res = gdm_settings_direct_get_string (GDM_KEY_TIMED_LOGIN_USER, &username);
-        if (res && (username == NULL || username[0] == '\0')) {
-                enabled = FALSE;
-                g_free (username);
-                username = NULL;
-                goto out;
-        }
-
-        delay = 0;
-        res = gdm_settings_direct_get_int (GDM_KEY_TIMED_LOGIN_DELAY, &delay);
-
-        if (res && delay <= 0) {
-                /* we don't allow the timed login to have a zero delay */
-                delay = 10;
-        }
-
- out:
-        if (enabledp != NULL) {
-                *enabledp = enabled;
-        }
-        if (usernamep != NULL) {
-                *usernamep = username;
-        } else {
-                g_free (username);
-        }
-        if (delayp != NULL) {
-                *delayp = delay;
-        }
-
-        if (enabled) {
-                g_debug ("GdmDisplay: Got timed login details for display %s: %d %s %d",
-                         self->priv->x11_display_name,
-                         enabled,
-                         username,
-                         delay);
-        } else {
-                g_debug ("GdmDisplay: Got timed login details for display %s: 0",
-                         self->priv->x11_display_name);
-        }
-}
-
 gboolean
 gdm_display_remove_user_authorization (GdmDisplay *self,
                                        const char *username,
@@ -819,6 +729,7 @@ static void
 _gdm_display_set_id (GdmDisplay     *self,
                      const char     *id)
 {
+        g_debug ("GdmDisplay: id: %s", id);
         g_free (self->priv->id);
         self->priv->id = g_strdup (id);
 }
@@ -827,6 +738,7 @@ static void
 _gdm_display_set_seat_id (GdmDisplay     *self,
                           const char     *seat_id)
 {
+        g_debug ("GdmDisplay: seat id: %s", seat_id);
         g_free (self->priv->seat_id);
         self->priv->seat_id = g_strdup (seat_id);
 }
@@ -835,6 +747,7 @@ static void
 _gdm_display_set_session_id (GdmDisplay     *self,
                              const char     *session_id)
 {
+        g_debug ("GdmDisplay: session id: %s", session_id);
         g_free (self->priv->session_id);
         self->priv->session_id = g_strdup (session_id);
 }
@@ -843,6 +756,7 @@ static void
 _gdm_display_set_session_class (GdmDisplay *self,
                                 const char *session_class)
 {
+        g_debug ("GdmDisplay: session class: %s", session_class);
         g_free (self->priv->session_class);
         self->priv->session_class = g_strdup (session_class);
 }
@@ -851,6 +765,7 @@ static void
 _gdm_display_set_session_type (GdmDisplay *self,
                                const char *session_type)
 {
+        g_debug ("GdmDisplay: session type: %s", session_type);
         g_free (self->priv->session_type);
         self->priv->session_type = g_strdup (session_type);
 }
@@ -890,6 +805,7 @@ static void
 _gdm_display_set_is_local (GdmDisplay     *self,
                            gboolean        is_local)
 {
+        g_debug ("GdmDisplay: local: %s", is_local? "yes" : "no");
         self->priv->is_local = is_local;
 }
 
@@ -906,6 +822,7 @@ static void
 _gdm_display_set_is_initial (GdmDisplay     *self,
                              gboolean        initial)
 {
+        g_debug ("GdmDisplay: initial: %s", initial? "yes" : "no");
         self->priv->is_initial = initial;
 }
 
@@ -913,6 +830,7 @@ static void
 _gdm_display_set_allow_timed_login (GdmDisplay     *self,
                                     gboolean        allow_timed_login)
 {
+        g_debug ("GdmDisplay: allow timed login: %s", allow_timed_login? "yes" : "no");
         self->priv->allow_timed_login = allow_timed_login;
 }
 
