@@ -144,12 +144,6 @@ write_pid (void)
         atexit (delete_pid);
 }
 
-static void
-delete_first_run_marker (void)
-{
-        g_unlink (GDM_RAN_ONCE_MARKER_FILE);
-}
-
 static gboolean
 ensure_dir_with_perms (const char *path,
                        uid_t       uid,
@@ -395,9 +389,6 @@ main (int    argc,
         delete_pid ();
         write_pid ();
 
-        /* clean up any stale ran once marker file that may be lingering */
-        delete_first_run_marker ();
-
         g_chdir ("/");
 
         main_loop = g_main_loop_new (NULL, FALSE);
